@@ -27,7 +27,7 @@ def get_corpora(corpus_indices=None, output_folder=DEFAULT_OUTPUT_FOLDER):
     try:
         download_corpora(corpus_indices, output_folder)
         for index in corpus_indices:
-            folder_name = CORPORA_SOURCES[index]["properties"]['folder_name']
+            folder_name = CORPORA_SOURCES[index]["properties"]['slug']
             gen_path = Path(output_folder) / folder_name / "averell"
             get_features = getattr(importlib.import_module(
                 CORPORA_SOURCES[index]["properties"]["reader"]), "get_features")
@@ -48,7 +48,9 @@ def get_corpora(corpus_indices=None, output_folder=DEFAULT_OUTPUT_FOLDER):
         return corpora_features
 
 
-def export_corpora(corpus_ids, granularity, corpora_folder, filename):
+def export_corpora(
+    corpus_ids, granularity, corpora_folder, filename, no_download=False
+):
     """
     Generates a single JSON file with the chosen granularity for all of the
         selected corpora
@@ -57,28 +59,34 @@ def export_corpora(corpus_ids, granularity, corpora_folder, filename):
     :param granularity: Level of parsing granularity
     :param corpora_folder: Local folder where the corpora is located
     :param filename: Name of the output file
+    :param no_download: Whether to download or not a corpora when missing
     :return: Python dict with the chosen granularity for all of the selected
         corpora
     """
     corpora_features = []
-    if Path(corpora_folder).exists():
+    slugs = []
+    if Path(corpora_folder).exists() or not no_download:
         if not corpus_ids:
             logging.error("No CORPUS ID selected")
         else:
             if granularity is not None:
-                for index in corpus_ids:
-                    corpus_id = index - 1
+                for corpus_id in corpus_ids:
                     try:
                         corpus = CORPORA_SOURCES[corpus_id]
                     except IndexError:
                         logging.error("ID not in corpora list")
                     else:
-                        corpus_folder = corpus["properties"]["folder_name"]
+                        corpus_folder = corpus["properties"]["slug"]
+                        slugs.append(corpus_folder)
                         corpus_name = corpus["name"]
                         if not (Path(corpora_folder) / corpus_folder).exists():
-                            logging.error(f'"{corpus_name}" not found in '
-                                          f'"{corpora_folder}" folder')
-                            continue
+                            if not no_download:
+                                get_corpora([corpus_id], corpora_folder)
+                            else:
+                                logging.error(
+                                    f'"{corpus_name} ({corpus_folder})" not '
+                                    f'found in "{corpora_folder}" folder')
+                                continue
                         granularities_list = corpus["properties"]["granularity"]
                         if granularity not in granularities_list:
                             logging.error(
@@ -94,11 +102,12 @@ def export_corpora(corpus_ids, granularity, corpora_folder, filename):
             else:
                 logging.error("No GRANULARITY selected")
         if corpora_features:
-            export_filename = filename
-            if not filename:
-                export_filename = granularity
-            write_json(corpora_features,
-                       str(Path(corpora_folder) / export_filename))
+            if filename:
+                export_filename = filename
+            else:
+                export_filename = "_".join(slugs)
+                export_filename = f"{export_filename}_{granularity}s"
+            write_json(corpora_features, export_filename)
     else:
         logging.error("Corpora folder not found")
     return corpora_features
